@@ -12,7 +12,7 @@ from textblob import TextBlob
 class process_text:
 
     def __init__(self):
-        self.__version__ = "1.2.1"
+        self.__version__ = "1.5.0"
         self.nlp = spacy.load("en_core_web_sm")
         self.path = r".\\TextPreprocessing"
         self.abbreviations = {
@@ -365,6 +365,16 @@ class process_text:
     def correct_spelling(self, text):
         return TextBlob(text).correct()
     
+    def clear_generic_entities(self, text):
+        document = self.nlp(text)
+        items = [ent.text for ent in doc.ents if ent.label_ == 'PERSON' or ent.label_ == 'ORDINAL' or ent.label_ == 'DATE']
+        for char in set(items):
+            char = re.sub("'", "", char)
+	        text = re.sub("("+char+")", " ", text)
+        text = " ".join([w for w in text.split()])
+        return text
+
+
     def lemetize(self, text):
         text = str(text)
         texts = []
